# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/bigquery_datatransfer_v1/proto/transfer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/bigquery_datatransfer_v1/proto/transfer.proto",
    package="google.cloud.bigquery.datatransfer.v1",
    syntax="proto3",
    serialized_options=b"\n)com.google.cloud.bigquery.datatransfer.v1B\rTransferProtoP\001ZQgoogle.golang.org/genproto/googleapis/cloud/bigquery/datatransfer/v1;datatransfer\242\002\005GCBDT\252\002%Google.Cloud.BigQuery.DataTransfer.V1\312\002%Google\\Cloud\\BigQuery\\DataTransfer\\V1\352\002)Google::Cloud::Bigquery::DataTransfer::V1",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n:google/cloud/bigquery_datatransfer_v1/proto/transfer.proto\x12%google.cloud.bigquery.datatransfer.v1\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x17google/rpc/status.proto"0\n\x10\x45mailPreferences\x12\x1c\n\x14\x65nable_failure_email\x18\x01 \x01(\x08"\x90\x01\n\x0fScheduleOptions\x12\x1f\n\x17\x64isable_auto_scheduling\x18\x03 \x01(\x08\x12.\n\nstart_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp"\xd7\x06\n\x0eTransferConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12 \n\x16\x64\x65stination_dataset_id\x18\x02 \x01(\tH\x00\x12\x14\n\x0c\x64isplay_name\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x05 \x01(\t\x12\'\n\x06params\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12P\n\x10schedule_options\x18\x18 \x01(\x0b\x32\x36.google.cloud.bigquery.datatransfer.v1.ScheduleOptions\x12 \n\x18\x64\x61ta_refresh_window_days\x18\x0c \x01(\x05\x12\x10\n\x08\x64isabled\x18\r \x01(\x08\x12\x34\n\x0bupdate_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x36\n\rnext_run_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12H\n\x05state\x18\n \x01(\x0e\x32\x34.google.cloud.bigquery.datatransfer.v1.TransferStateB\x03\xe0\x41\x03\x12\x0f\n\x07user_id\x18\x0b \x01(\x03\x12\x1b\n\x0e\x64\x61taset_region\x18\x0e \x01(\tB\x03\xe0\x41\x03\x12!\n\x19notification_pubsub_topic\x18\x0f \x01(\t\x12R\n\x11\x65mail_preferences\x18\x12 \x01(\x0b\x32\x37.google.cloud.bigquery.datatransfer.v1.EmailPreferences:\xb9\x01\xea\x41\xb5\x01\n2bigquerydatatransfer.googleapis.com/TransferConfig\x12\x34projects/{project}/transferConfigs/{transfer_config}\x12Iprojects/{project}/locations/{location}/transferConfigs/{transfer_config}B\r\n\x0b\x64\x65stination"\xfa\x06\n\x0bTransferRun\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n\rschedule_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08run_time\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x0c\x65rror_status\x18\x15 \x01(\x0b\x32\x12.google.rpc.Status\x12\x33\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x31\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12\x34\n\x0bupdate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x03\xe0\x41\x03\x12,\n\x06params\x18\t \x01(\x0b\x32\x17.google.protobuf.StructB\x03\xe0\x41\x03\x12%\n\x16\x64\x65stination_dataset_id\x18\x02 \x01(\tB\x03\xe0\x41\x03H\x00\x12\x1b\n\x0e\x64\x61ta_source_id\x18\x07 \x01(\tB\x03\xe0\x41\x03\x12\x43\n\x05state\x18\x08 \x01(\x0e\x32\x34.google.cloud.bigquery.datatransfer.v1.TransferState\x12\x0f\n\x07user_id\x18\x0b \x01(\x03\x12\x15\n\x08schedule\x18\x0c \x01(\tB\x03\xe0\x41\x03\x12&\n\x19notification_pubsub_topic\x18\x17 \x01(\tB\x03\xe0\x41\x03\x12W\n\x11\x65mail_preferences\x18\x19 \x01(\x0b\x32\x37.google.cloud.bigquery.datatransfer.v1.EmailPreferencesB\x03\xe0\x41\x03:\xc4\x01\xea\x41\xc0\x01\n\'bigquerydatatransfer.googleapis.com/Run\x12?projects/{project}/transferConfigs/{transfer_config}/runs/{run}\x12Tprojects/{project}/locations/{location}/transferConfigs/{transfer_config}/runs/{run}B\r\n\x0b\x64\x65stination"\x8a\x02\n\x0fTransferMessage\x12\x30\n\x0cmessage_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12X\n\x08severity\x18\x02 \x01(\x0e\x32\x46.google.cloud.bigquery.datatransfer.v1.TransferMessage.MessageSeverity\x12\x14\n\x0cmessage_text\x18\x03 \x01(\t"U\n\x0fMessageSeverity\x12 \n\x1cMESSAGE_SEVERITY_UNSPECIFIED\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03*K\n\x0cTransferType\x12\x1d\n\x19TRANSFER_TYPE_UNSPECIFIED\x10\x00\x12\t\n\x05\x42\x41TCH\x10\x01\x12\r\n\tSTREAMING\x10\x02\x1a\x02\x18\x01*s\n\rTransferState\x12\x1e\n\x1aTRANSFER_STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x02\x12\x0b\n\x07RUNNING\x10\x03\x12\r\n\tSUCCEEDED\x10\x04\x12\n\n\x06\x46\x41ILED\x10\x05\x12\r\n\tCANCELLED\x10\x06\x42\x93\x02\n)com.google.cloud.bigquery.datatransfer.v1B\rTransferProtoP\x01ZQgoogle.golang.org/genproto/googleapis/cloud/bigquery/datatransfer/v1;datatransfer\xa2\x02\x05GCBDT\xaa\x02%Google.Cloud.BigQuery.DataTransfer.V1\xca\x02%Google\\Cloud\\BigQuery\\DataTransfer\\V1\xea\x02)Google::Cloud::Bigquery::DataTransfer::V1b\x06proto3',
    dependencies=[
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        google_dot_rpc_dot_status__pb2.DESCRIPTOR,
    ],
)

_TRANSFERTYPE = _descriptor.EnumDescriptor(
    name="TransferType",
    full_name="google.cloud.bigquery.datatransfer.v1.TransferType",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TRANSFER_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="BATCH",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="STREAMING",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=b"\030\001",
    serialized_start=2466,
    serialized_end=2541,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERTYPE)

TransferType = enum_type_wrapper.EnumTypeWrapper(_TRANSFERTYPE)
_TRANSFERSTATE = _descriptor.EnumDescriptor(
    name="TransferState",
    full_name="google.cloud.bigquery.datatransfer.v1.TransferState",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TRANSFER_STATE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="PENDING",
            index=1,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="RUNNING",
            index=2,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="SUCCEEDED",
            index=3,
            number=4,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="FAILED",
            index=4,
            number=5,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="CANCELLED",
            index=5,
            number=6,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2543,
    serialized_end=2658,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERSTATE)

TransferState = enum_type_wrapper.EnumTypeWrapper(_TRANSFERSTATE)
TRANSFER_TYPE_UNSPECIFIED = 0
BATCH = 1
STREAMING = 2
TRANSFER_STATE_UNSPECIFIED = 0
PENDING = 2
RUNNING = 3
SUCCEEDED = 4
FAILED = 5
CANCELLED = 6


_TRANSFERMESSAGE_MESSAGESEVERITY = _descriptor.EnumDescriptor(
    name="MessageSeverity",
    full_name="google.cloud.bigquery.datatransfer.v1.TransferMessage.MessageSeverity",
    filename=None,
    file=DESCRIPTOR,
    create_key=_descriptor._internal_create_key,
    values=[
        _descriptor.EnumValueDescriptor(
            name="MESSAGE_SEVERITY_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="INFO",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="WARNING",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.EnumValueDescriptor(
            name="ERROR",
            index=3,
            number=3,
            serialized_options=None,
            type=None,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2379,
    serialized_end=2464,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERMESSAGE_MESSAGESEVERITY)


_EMAILPREFERENCES = _descriptor.Descriptor(
    name="EmailPreferences",
    full_name="google.cloud.bigquery.datatransfer.v1.EmailPreferences",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="enable_failure_email",
            full_name="google.cloud.bigquery.datatransfer.v1.EmailPreferences.enable_failure_email",
            index=0,
            number=1,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=249,
    serialized_end=297,
)


_SCHEDULEOPTIONS = _descriptor.Descriptor(
    name="ScheduleOptions",
    full_name="google.cloud.bigquery.datatransfer.v1.ScheduleOptions",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="disable_auto_scheduling",
            full_name="google.cloud.bigquery.datatransfer.v1.ScheduleOptions.disable_auto_scheduling",
            index=0,
            number=3,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="start_time",
            full_name="google.cloud.bigquery.datatransfer.v1.ScheduleOptions.start_time",
            index=1,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="google.cloud.bigquery.datatransfer.v1.ScheduleOptions.end_time",
            index=2,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=300,
    serialized_end=444,
)


_TRANSFERCONFIG = _descriptor.Descriptor(
    name="TransferConfig",
    full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="destination_dataset_id",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.destination_dataset_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.display_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_source_id",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.data_source_id",
            index=3,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.params",
            index=4,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schedule",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.schedule",
            index=5,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schedule_options",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.schedule_options",
            index=6,
            number=24,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_refresh_window_days",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.data_refresh_window_days",
            index=7,
            number=12,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="disabled",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.disabled",
            index=8,
            number=13,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.update_time",
            index=9,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_run_time",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.next_run_time",
            index=10,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="state",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.state",
            index=11,
            number=10,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="user_id",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.user_id",
            index=12,
            number=11,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="dataset_region",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.dataset_region",
            index=13,
            number=14,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="notification_pubsub_topic",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.notification_pubsub_topic",
            index=14,
            number=15,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="email_preferences",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.email_preferences",
            index=15,
            number=18,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A\265\001\n2bigquerydatatransfer.googleapis.com/TransferConfig\0224projects/{project}/transferConfigs/{transfer_config}\022Iprojects/{project}/locations/{location}/transferConfigs/{transfer_config}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferConfig.destination",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=447,
    serialized_end=1302,
)


_TRANSFERRUN = _descriptor.Descriptor(
    name="TransferRun",
    full_name="google.cloud.bigquery.datatransfer.v1.TransferRun",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schedule_time",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.schedule_time",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="run_time",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.run_time",
            index=2,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="error_status",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.error_status",
            index=3,
            number=21,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="start_time",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.start_time",
            index=4,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="end_time",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.end_time",
            index=5,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.update_time",
            index=6,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="params",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.params",
            index=7,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="destination_dataset_id",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.destination_dataset_id",
            index=8,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="data_source_id",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.data_source_id",
            index=9,
            number=7,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="state",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.state",
            index=10,
            number=8,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="user_id",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.user_id",
            index=11,
            number=11,
            type=3,
            cpp_type=2,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="schedule",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.schedule",
            index=12,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="notification_pubsub_topic",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.notification_pubsub_topic",
            index=13,
            number=23,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="email_preferences",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.email_preferences",
            index=14,
            number=25,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A\300\001\n'bigquerydatatransfer.googleapis.com/Run\022?projects/{project}/transferConfigs/{transfer_config}/runs/{run}\022Tprojects/{project}/locations/{location}/transferConfigs/{transfer_config}/runs/{run}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="destination",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferRun.destination",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=1305,
    serialized_end=2195,
)


_TRANSFERMESSAGE = _descriptor.Descriptor(
    name="TransferMessage",
    full_name="google.cloud.bigquery.datatransfer.v1.TransferMessage",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="message_time",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferMessage.message_time",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="severity",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferMessage.severity",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="message_text",
            full_name="google.cloud.bigquery.datatransfer.v1.TransferMessage.message_text",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_TRANSFERMESSAGE_MESSAGESEVERITY,],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2198,
    serialized_end=2464,
)

_SCHEDULEOPTIONS.fields_by_name[
    "start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SCHEDULEOPTIONS.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERCONFIG.fields_by_name[
    "params"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_TRANSFERCONFIG.fields_by_name["schedule_options"].message_type = _SCHEDULEOPTIONS
_TRANSFERCONFIG.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERCONFIG.fields_by_name[
    "next_run_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERCONFIG.fields_by_name["state"].enum_type = _TRANSFERSTATE
_TRANSFERCONFIG.fields_by_name["email_preferences"].message_type = _EMAILPREFERENCES
_TRANSFERCONFIG.oneofs_by_name["destination"].fields.append(
    _TRANSFERCONFIG.fields_by_name["destination_dataset_id"]
)
_TRANSFERCONFIG.fields_by_name[
    "destination_dataset_id"
].containing_oneof = _TRANSFERCONFIG.oneofs_by_name["destination"]
_TRANSFERRUN.fields_by_name[
    "schedule_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERRUN.fields_by_name[
    "run_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERRUN.fields_by_name[
    "error_status"
].message_type = google_dot_rpc_dot_status__pb2._STATUS
_TRANSFERRUN.fields_by_name[
    "start_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERRUN.fields_by_name[
    "end_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERRUN.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERRUN.fields_by_name[
    "params"
].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_TRANSFERRUN.fields_by_name["state"].enum_type = _TRANSFERSTATE
_TRANSFERRUN.fields_by_name["email_preferences"].message_type = _EMAILPREFERENCES
_TRANSFERRUN.oneofs_by_name["destination"].fields.append(
    _TRANSFERRUN.fields_by_name["destination_dataset_id"]
)
_TRANSFERRUN.fields_by_name[
    "destination_dataset_id"
].containing_oneof = _TRANSFERRUN.oneofs_by_name["destination"]
_TRANSFERMESSAGE.fields_by_name[
    "message_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERMESSAGE.fields_by_name["severity"].enum_type = _TRANSFERMESSAGE_MESSAGESEVERITY
_TRANSFERMESSAGE_MESSAGESEVERITY.containing_type = _TRANSFERMESSAGE
DESCRIPTOR.message_types_by_name["EmailPreferences"] = _EMAILPREFERENCES
DESCRIPTOR.message_types_by_name["ScheduleOptions"] = _SCHEDULEOPTIONS
DESCRIPTOR.message_types_by_name["TransferConfig"] = _TRANSFERCONFIG
DESCRIPTOR.message_types_by_name["TransferRun"] = _TRANSFERRUN
DESCRIPTOR.message_types_by_name["TransferMessage"] = _TRANSFERMESSAGE
DESCRIPTOR.enum_types_by_name["TransferType"] = _TRANSFERTYPE
DESCRIPTOR.enum_types_by_name["TransferState"] = _TRANSFERSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

EmailPreferences = _reflection.GeneratedProtocolMessageType(
    "EmailPreferences",
    (_message.Message,),
    {
        "DESCRIPTOR": _EMAILPREFERENCES,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.transfer_pb2",
        "__doc__": """Represents preferences for sending email notifications for transfer
  run events.
  
  Attributes:
      enable_failure_email:
          If true, email notifications will be sent on transfer run
          failures.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.EmailPreferences)
    },
)
_sym_db.RegisterMessage(EmailPreferences)

ScheduleOptions = _reflection.GeneratedProtocolMessageType(
    "ScheduleOptions",
    (_message.Message,),
    {
        "DESCRIPTOR": _SCHEDULEOPTIONS,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.transfer_pb2",
        "__doc__": """Options customizing the data transfer schedule.
  
  Attributes:
      disable_auto_scheduling:
          If true, automatic scheduling of data transfer runs for this
          configuration will be disabled. The runs can be started on ad-
          hoc basis using StartManualTransferRuns API. When automatic
          scheduling is disabled, the TransferConfig.schedule field will
          be ignored.
      start_time:
          Specifies time to start scheduling transfer runs. The first
          run will be scheduled at or after the start time according to
          a recurrence pattern defined in the schedule string. The start
          time can be changed at any moment. The time when a data
          transfer can be trigerred manually is not limited by this
          option.
      end_time:
          Defines time to stop scheduling transfer runs. A transfer run
          cannot be scheduled at or after the end time. The end time can
          be changed at any moment. The time when a data transfer can be
          trigerred manually is not limited by this option.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.ScheduleOptions)
    },
)
_sym_db.RegisterMessage(ScheduleOptions)

TransferConfig = _reflection.GeneratedProtocolMessageType(
    "TransferConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _TRANSFERCONFIG,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.transfer_pb2",
        "__doc__": """Represents a data transfer configuration. A transfer configuration
  contains all metadata needed to perform a data transfer. For example,
  ``destination_dataset_id`` specifies where data should be stored. When
  a new transfer configuration is created, the specified
  ``destination_dataset_id`` is created when needed and shared with the
  appropriate data source service account.
  
  Attributes:
      name:
          The resource name of the transfer config. Transfer config
          names have the form of ``projects/{project_id}/locations/{regi
          on}/transferConfigs/{config_id}``. The name is automatically
          generated based on the config_id specified in
          CreateTransferConfigRequest along with project_id and region.
          If config_id is not provided, usually a uuid, even though it
          is not guaranteed or required, will be generated for
          config_id.
      destination:
          The desination of the transfer config.
      destination_dataset_id:
          The BigQuery target dataset id.
      display_name:
          User specified display name for the data transfer.
      data_source_id:
          Data source id. Cannot be changed once data transfer is
          created.
      params:
          Data transfer specific parameters.
      schedule:
          Data transfer schedule. If the data source does not support a
          custom schedule, this should be empty. If it is empty, the
          default value for the data source will be used. The specified
          times are in UTC. Examples of valid format: ``1st,3rd monday
          of month 15:30``, ``every wed,fri of jan,jun 13:15``, and
          ``first sunday of quarter 00:00``. See more explanation about
          the format here: https://cloud.google.com/appengine/docs/flexi
          ble/python/scheduling-jobs-with-cron-yaml#the_schedule_format
          NOTE: the granularity should be at least 8 hours, or less
          frequent.
      schedule_options:
          Options customizing the data transfer schedule.
      data_refresh_window_days:
          The number of days to look back to automatically refresh the
          data. For example, if ``data_refresh_window_days = 10``, then
          every day BigQuery reingests data for [today-10, today-1],
          rather than ingesting data for just [today-1]. Only valid if
          the data source supports the feature. Set the value to 0 to
          use the default value.
      disabled:
          Is this config disabled. When set to true, no runs are
          scheduled for a given transfer.
      update_time:
          Output only. Data transfer modification time. Ignored by
          server on input.
      next_run_time:
          Output only. Next time when data transfer will run.
      state:
          Output only. State of the most recently updated transfer run.
      user_id:
          Deprecated. Unique ID of the user on whose behalf transfer is
          done.
      dataset_region:
          Output only. Region in which BigQuery dataset is located.
      notification_pubsub_topic:
          Pub/Sub topic where notifications will be sent after transfer
          runs associated with this transfer config finish.
      email_preferences:
          Email notifications will be sent according to these
          preferences to the email address of the user who owns this
          transfer config.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.TransferConfig)
    },
)
_sym_db.RegisterMessage(TransferConfig)

TransferRun = _reflection.GeneratedProtocolMessageType(
    "TransferRun",
    (_message.Message,),
    {
        "DESCRIPTOR": _TRANSFERRUN,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.transfer_pb2",
        "__doc__": """Represents a data transfer run.
  
  Attributes:
      name:
          The resource name of the transfer run. Transfer run names have
          the form ``projects/{project_id}/locations/{location}/transfer
          Configs/{config_id}/runs/{run_id}``. The name is ignored when
          creating a transfer run.
      schedule_time:
          Minimum time after which a transfer run can be started.
      run_time:
          For batch transfer runs, specifies the date and time of the
          data should be ingested.
      error_status:
          Status of the transfer run.
      start_time:
          Output only. Time when transfer run was started. Parameter
          ignored by server for input requests.
      end_time:
          Output only. Time when transfer run ended. Parameter ignored
          by server for input requests.
      update_time:
          Output only. Last time the data transfer run state was
          updated.
      params:
          Output only. Data transfer specific parameters.
      destination:
          Data transfer destination.
      destination_dataset_id:
          Output only. The BigQuery target dataset id.
      data_source_id:
          Output only. Data source id.
      state:
          Data transfer run state. Ignored for input requests.
      user_id:
          Deprecated. Unique ID of the user on whose behalf transfer is
          done.
      schedule:
          Output only. Describes the schedule of this transfer run if it
          was created as part of a regular schedule. For batch transfer
          runs that are scheduled manually, this is empty. NOTE: the
          system might choose to delay the schedule depending on the
          current load, so ``schedule_time`` doesn’t always match this.
      notification_pubsub_topic:
          Output only. Pub/Sub topic where a notification will be sent
          after this transfer run finishes
      email_preferences:
          Output only. Email notifications will be sent according to
          these preferences to the email address of the user who owns
          the transfer config this run was derived from.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.TransferRun)
    },
)
_sym_db.RegisterMessage(TransferRun)

TransferMessage = _reflection.GeneratedProtocolMessageType(
    "TransferMessage",
    (_message.Message,),
    {
        "DESCRIPTOR": _TRANSFERMESSAGE,
        "__module__": "google.cloud.bigquery_datatransfer_v1.proto.transfer_pb2",
        "__doc__": """Represents a user facing message for a particular data transfer run.
  
  Attributes:
      message_time:
          Time when message was logged.
      severity:
          Message severity.
      message_text:
          Message text.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.bigquery.datatransfer.v1.TransferMessage)
    },
)
_sym_db.RegisterMessage(TransferMessage)


DESCRIPTOR._options = None
_TRANSFERTYPE._options = None
_TRANSFERCONFIG.fields_by_name["update_time"]._options = None
_TRANSFERCONFIG.fields_by_name["next_run_time"]._options = None
_TRANSFERCONFIG.fields_by_name["state"]._options = None
_TRANSFERCONFIG.fields_by_name["dataset_region"]._options = None
_TRANSFERCONFIG._options = None
_TRANSFERRUN.fields_by_name["start_time"]._options = None
_TRANSFERRUN.fields_by_name["end_time"]._options = None
_TRANSFERRUN.fields_by_name["update_time"]._options = None
_TRANSFERRUN.fields_by_name["params"]._options = None
_TRANSFERRUN.fields_by_name["destination_dataset_id"]._options = None
_TRANSFERRUN.fields_by_name["data_source_id"]._options = None
_TRANSFERRUN.fields_by_name["schedule"]._options = None
_TRANSFERRUN.fields_by_name["notification_pubsub_topic"]._options = None
_TRANSFERRUN.fields_by_name["email_preferences"]._options = None
_TRANSFERRUN._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.cloud.bigquery_datatransfer_v1.proto import (
    datatransfer_pb2 as google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2,
)
from google.cloud.bigquery_datatransfer_v1.proto import (
    transfer_pb2 as google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2,
)
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


class DataTransferServiceStub(object):
    """The Google BigQuery Data Transfer Service API enables BigQuery users to
    configure the transfer of their data from other Google Products into
    BigQuery. This service contains methods that are end user exposed. It backs
    up the frontend.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetDataSource = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/GetDataSource",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.GetDataSourceRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.DataSource.FromString,
        )
        self.ListDataSources = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ListDataSources",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListDataSourcesRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListDataSourcesResponse.FromString,
        )
        self.CreateTransferConfig = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/CreateTransferConfig",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.CreateTransferConfigRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferConfig.FromString,
        )
        self.UpdateTransferConfig = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/UpdateTransferConfig",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.UpdateTransferConfigRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferConfig.FromString,
        )
        self.DeleteTransferConfig = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/DeleteTransferConfig",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.DeleteTransferConfigRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.GetTransferConfig = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/GetTransferConfig",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.GetTransferConfigRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferConfig.FromString,
        )
        self.ListTransferConfigs = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ListTransferConfigs",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferConfigsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferConfigsResponse.FromString,
        )
        self.ScheduleTransferRuns = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ScheduleTransferRuns",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ScheduleTransferRunsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ScheduleTransferRunsResponse.FromString,
        )
        self.StartManualTransferRuns = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/StartManualTransferRuns",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.StartManualTransferRunsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.StartManualTransferRunsResponse.FromString,
        )
        self.GetTransferRun = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/GetTransferRun",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.GetTransferRunRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferRun.FromString,
        )
        self.DeleteTransferRun = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/DeleteTransferRun",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.DeleteTransferRunRequest.SerializeToString,
            response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
        )
        self.ListTransferRuns = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ListTransferRuns",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferRunsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferRunsResponse.FromString,
        )
        self.ListTransferLogs = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ListTransferLogs",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferLogsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferLogsResponse.FromString,
        )
        self.CheckValidCreds = channel.unary_unary(
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/CheckValidCreds",
            request_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.CheckValidCredsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.CheckValidCredsResponse.FromString,
        )


class DataTransferServiceServicer(object):
    """The Google BigQuery Data Transfer Service API enables BigQuery users to
    configure the transfer of their data from other Google Products into
    BigQuery. This service contains methods that are end user exposed. It backs
    up the frontend.
    """

    def GetDataSource(self, request, context):
        """Retrieves a supported data source and returns its settings,
        which can be used for UI rendering.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListDataSources(self, request, context):
        """Lists supported data sources and returns their settings,
        which can be used for UI rendering.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateTransferConfig(self, request, context):
        """Creates a new data transfer configuration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateTransferConfig(self, request, context):
        """Updates a data transfer configuration.
        All fields must be set, even if they are not updated.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteTransferConfig(self, request, context):
        """Deletes a data transfer configuration,
        including any associated transfer runs and logs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTransferConfig(self, request, context):
        """Returns information about a data transfer config.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListTransferConfigs(self, request, context):
        """Returns information about all data transfers in the project.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ScheduleTransferRuns(self, request, context):
        """Creates transfer runs for a time range [start_time, end_time].
        For each date - or whatever granularity the data source supports - in the
        range, one transfer run is created.
        Note that runs are created per UTC time in the time range.
        DEPRECATED: use StartManualTransferRuns instead.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def StartManualTransferRuns(self, request, context):
        """Start manual transfer runs to be executed now with schedule_time equal to
        current time. The transfer runs can be created for a time range where the
        run_time is between start_time (inclusive) and end_time (exclusive), or for
        a specific run_time.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTransferRun(self, request, context):
        """Returns information about the particular transfer run.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteTransferRun(self, request, context):
        """Deletes the specified transfer run.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListTransferRuns(self, request, context):
        """Returns information about running and completed jobs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListTransferLogs(self, request, context):
        """Returns user facing log messages for the data transfer run.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CheckValidCreds(self, request, context):
        """Returns true if valid credentials exist for the given data source and
        requesting user.
        Some data sources doesn't support service account, so we need to talk to
        them on behalf of the end user. This API just checks whether we have OAuth
        token for the particular user, which is a pre-requisite before user can
        create a transfer config.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_DataTransferServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "GetDataSource": grpc.unary_unary_rpc_method_handler(
            servicer.GetDataSource,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.GetDataSourceRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.DataSource.SerializeToString,
        ),
        "ListDataSources": grpc.unary_unary_rpc_method_handler(
            servicer.ListDataSources,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListDataSourcesRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListDataSourcesResponse.SerializeToString,
        ),
        "CreateTransferConfig": grpc.unary_unary_rpc_method_handler(
            servicer.CreateTransferConfig,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.CreateTransferConfigRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferConfig.SerializeToString,
        ),
        "UpdateTransferConfig": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTransferConfig,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.UpdateTransferConfigRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferConfig.SerializeToString,
        ),
        "DeleteTransferConfig": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTransferConfig,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.DeleteTransferConfigRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "GetTransferConfig": grpc.unary_unary_rpc_method_handler(
            servicer.GetTransferConfig,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.GetTransferConfigRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferConfig.SerializeToString,
        ),
        "ListTransferConfigs": grpc.unary_unary_rpc_method_handler(
            servicer.ListTransferConfigs,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferConfigsRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferConfigsResponse.SerializeToString,
        ),
        "ScheduleTransferRuns": grpc.unary_unary_rpc_method_handler(
            servicer.ScheduleTransferRuns,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ScheduleTransferRunsRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ScheduleTransferRunsResponse.SerializeToString,
        ),
        "StartManualTransferRuns": grpc.unary_unary_rpc_method_handler(
            servicer.StartManualTransferRuns,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.StartManualTransferRunsRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.StartManualTransferRunsResponse.SerializeToString,
        ),
        "GetTransferRun": grpc.unary_unary_rpc_method_handler(
            servicer.GetTransferRun,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.GetTransferRunRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferRun.SerializeToString,
        ),
        "DeleteTransferRun": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteTransferRun,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.DeleteTransferRunRequest.FromString,
            response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
        ),
        "ListTransferRuns": grpc.unary_unary_rpc_method_handler(
            servicer.ListTransferRuns,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferRunsRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferRunsResponse.SerializeToString,
        ),
        "ListTransferLogs": grpc.unary_unary_rpc_method_handler(
            servicer.ListTransferLogs,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferLogsRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferLogsResponse.SerializeToString,
        ),
        "CheckValidCreds": grpc.unary_unary_rpc_method_handler(
            servicer.CheckValidCreds,
            request_deserializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.CheckValidCredsRequest.FromString,
            response_serializer=google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.CheckValidCredsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.bigquery.datatransfer.v1.DataTransferService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class DataTransferService(object):
    """The Google BigQuery Data Transfer Service API enables BigQuery users to
    configure the transfer of their data from other Google Products into
    BigQuery. This service contains methods that are end user exposed. It backs
    up the frontend.
    """

    @staticmethod
    def GetDataSource(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/GetDataSource",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.GetDataSourceRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.DataSource.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListDataSources(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ListDataSources",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListDataSourcesRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListDataSourcesResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CreateTransferConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/CreateTransferConfig",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.CreateTransferConfigRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferConfig.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def UpdateTransferConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/UpdateTransferConfig",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.UpdateTransferConfigRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferConfig.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteTransferConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/DeleteTransferConfig",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.DeleteTransferConfigRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetTransferConfig(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/GetTransferConfig",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.GetTransferConfigRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferConfig.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListTransferConfigs(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ListTransferConfigs",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferConfigsRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferConfigsResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ScheduleTransferRuns(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ScheduleTransferRuns",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ScheduleTransferRunsRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ScheduleTransferRunsResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def StartManualTransferRuns(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/StartManualTransferRuns",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.StartManualTransferRunsRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.StartManualTransferRunsResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def GetTransferRun(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/GetTransferRun",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.GetTransferRunRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_transfer__pb2.TransferRun.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def DeleteTransferRun(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/DeleteTransferRun",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.DeleteTransferRunRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListTransferRuns(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ListTransferRuns",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferRunsRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferRunsResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ListTransferLogs(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/ListTransferLogs",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferLogsRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.ListTransferLogsResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def CheckValidCreds(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/google.cloud.bigquery.datatransfer.v1.DataTransferService/CheckValidCreds",
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.CheckValidCredsRequest.SerializeToString,
            google_dot_cloud_dot_bigquery__datatransfer__v1_dot_proto_dot_datatransfer__pb2.CheckValidCredsResponse.FromString,
            options,
            channel_credentials,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
